#include <gtk/gtk.h>


void
on_cbo_BaudRate_changed                (GtkComboBox     *combobox,
                                        gpointer         user_data);

void
on_btn_Write_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_bnt_Read_clicked                    (GtkButton       *button,
                                        gpointer         user_data);

void
on_btn_WriteRead_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_window1_destroy                     (GtkObject       *object,
                                        gpointer         user_data);

void
on_btn_WriteRead_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_chk_LoopBack_toggled                (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_combobox1_changed                   (GtkComboBox     *combobox,
                                        gpointer         user_data);

void
on_cbo_TTY_changed                     (GtkComboBox     *combobox,
                                        gpointer         user_data);

void
on_cbo_TTY_composited_changed          (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_cbo_UsbTty_changed                  (GtkComboBox     *combobox,
                                        gpointer         user_data);

void
on_cbo_Tty_changed                     (GtkComboBox     *combobox,
                                        gpointer         user_data);

void
on_btn_WriteFileOpen_file_set          (GtkFileChooserButton *filechooserbutton,
                                        gpointer         user_data);

void
on_btn_ReadFileOpen_file_set           (GtkFileChooserButton *filechooserbutton,
                                        gpointer         user_data);

void
on_btn_WriteRead_ReadOpen_file_set     (GtkFileChooserButton *filechooserbutton,
                                        gpointer         user_data);

void
on_btn_WriteRead_WriteOpen_file_set    (GtkFileChooserButton *filechooserbutton,
                                        gpointer         user_data);


void
on_btn_WriteOpen_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_btn_WriteRead_ReadOpen_clicked      (GtkButton       *button,
                                        gpointer         user_data);

void
on_btn_WriteRead_WriteOpen_clicked     (GtkButton       *button,
										GtkWindow *         user_data);

void
on_btn_ReadOpen_clicked                (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_notebook1_change_current_page       (GtkNotebook     *notebook,
                                        gint             offset,
                                        gpointer         user_data);

void
on_notebook1_switch_page               (GtkNotebook     *notebook,
                                        GtkNotebookPage *page,
                                        guint            page_num,
                                        gpointer         user_data);

void
on_txt_WriteSize_changed               (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_txt_ReadSize_changed                (GtkEditable     *editable,
                                        gpointer         user_data);
